#include "darwin_robot.h"
#include "darwin_robot_exceptions.h"
#include "action_id.h"

#include <iostream>

//std::string robot_device="A603LOBS";
std::string robot_device="A4008atn";

int main(int argc, char *argv[])
{
  int i=0,num_servos;
  std::vector<double> angles;

  try{
    CDarwinRobot darwin("Darwin",robot_device,1000000,0x02);
    num_servos=darwin.mm_get_num_servos();
    std::cout << "Found " << num_servos << " servos" << std::endl;
    // enable all servos and assign them to the action module
    darwin.mm_enable_power();
    for(i=1;i<=num_servos;i++)
    {
      darwin.mm_enable_servo(i);
      darwin.mm_assign_module(i,DARWIN_MM_ACTION);
    }
    darwin.mm_start();
    // execute an action
    darwin.action_load_page(WALK_READY);
    darwin.action_start();
    while(darwin.action_is_page_running())
      usleep(100000);
    for(i=1;i<=num_servos;i++)
      darwin.mm_assign_module(i,DARWIN_MM_WALKING);
    std::cout << "Start walking ..." << std::endl;
    darwin.walk_set_x_step(0.02);
    darwin.walk_set_y_step(0.0);
    darwin.walk_set_turn_step(0.0);
    darwin.walk_start();
    sleep(2);
    std::cout << "Stop walking ..." << std::endl;
    darwin.walk_stop();
    while(darwin.is_walking())
    {
      std::cout << "Walking ..." << std::endl;
      usleep(100000);
    }
    darwin.mm_stop();
    darwin.mm_disable_power();
  }catch(CException &e){
    std::cout << e.what() << std::endl;
  }
}
